@@ -55,6 +55,7 @@ spec:
     systemd: {}
   fips: false
   kernelArguments: null
+  kernelType: ""
   osImageURL: ""
 `},
 		},
@@ -91,6 +92,7 @@ spec:
     systemd: {}
   fips: false
   kernelArguments: null
+  kernelType: ""
   osImageURL: ""
 `},
 		},
@@ -128,6 +130,7 @@ spec:
     systemd: {}
   fips: false
   kernelArguments: null
+  kernelType: ""
   osImageURL: ""
 `, `apiVersion: machineconfiguration.openshift.io/v1
 kind: MachineConfig
@@ -154,6 +157,7 @@ spec:
     systemd: {}
   fips: false
   kernelArguments: null
+  kernelType: ""
   osImageURL: ""
 `},
 		},
@@ -183,7 +187,8 @@ spec:
 							Replicas:       pointer.Int64Ptr(1),
 							Platform: types.MachinePoolPlatform{
 								AWS: &awstypes.MachinePool{
-									Zones: []string{"us-east-1a"},
+									Zones:        []string{"us-east-1a"},
+									InstanceType: "m4.xlarge",
 								},
 							},
 						},
